module ALU(
    input [31:0] srcA, srcB,
    input [3:0] aluControl,
    output reg [31:0] aluResult,
    output zero
);
    always @(*) begin
        case (aluControl)
            4'b0000: aluResult = srcA + srcB;   // ADD
            4'b0001: aluResult = srcA - srcB;   // SUB
            4'b0010: aluResult = srcA & srcB;   // AND
            4'b0011: aluResult = srcA | srcB;   // OR
            4'b0100: aluResult = srcA ^ srcB;   // XOR
            4'b0101: aluResult = srcA << srcB[4:0]; // SLL
            4'b0110: aluResult = srcA >> srcB[4:0]; // SRL
            4'b0111: aluResult = $signed(srcA) >>> srcB[4:0]; // SRA
            4'b1000: aluResult = (srcA < srcB) ? 32'd1 : 32'd0; // SLT
            4'b1001: aluResult = ($signed(srcA) < $signed(srcB)) ? 32'd1 : 32'd0; // SLTU
            default: aluResult = 32'b0;
        endcase
    end

    assign zero = (aluResult == 32'b0) ? 1'b1 : 1'b0;
endmodule